<template>
  <ProDialog
    title="上传投保人员清单"
    v-model="innerVisible"
    destroy-on-close
    :close-on-click-modal="false"
    :close-on-press-escape="false"
    draggable
    bodyNoPaddingBottom
    @close="onDialogClose"
    width="600px"
  >
    <ProForm :model="innerForm" ref="dialogForm" label-width="100px">
      <ProFormItemV2
        label="投保产品："
        prop="productIdNumber"
        :check-rules="[{ message: '请选择投保产品' }]"
        v-if="allUserInsureProductSettingList.length > 0"
      >
        <ProFormSelect
          placeholder="请选择投保产品"
          :value-enum="allUserInsureProductSettingList"
          clearable
          v-model="form.productIdNumber"
          enum-label-key="insuranceScheme"
          enum-value-key="productIdNumber"
        ></ProFormSelect>
      </ProFormItemV2>
      <ProFormItemV2 label="批次号：" prop="serialNum" :check-rules="[{ message: '请输入批次号' }]">
        <ProFormText
          placeholder="请输入批次号"
          v-model.trim="innerForm.serialNum"
          :maxlength="30"
        ></ProFormText>
      </ProFormItemV2>
      <ProFormItemV2
        label="上传文件："
        prop="url"
        :check-rules="[{ message: '请上传文件', type: 'upload' }]"
      >
        <ProFormUpload
          v-model:file-url="innerForm.url"
          :limit="1"
          :limitFileSize="10"
          accept="xlsx,xls"
        >
          <template #tip>
            <div>
              <el-text type="danger">支持excel文件，请上传同批次的投保人员清单</el-text>
            </div>
          </template>
        </ProFormUpload>
      </ProFormItemV2>
    </ProForm>
    <template #footer>
      <span class="dialog-footer">
        <el-button type="primary" @click="handleConfirm">确 定</el-button>
      </span>
    </template>
  </ProDialog>
</template>

<script setup lang="ts">
import { useUserInsureProductSetting } from '@/hooks';
import {
  ProDialog,
  UploadUserFile,
  ProForm,
  ProFormItemV2,
  ProFormText,
  ProFormUpload,
  ProFormSelect,
} from '@bole-core/components';
import { FormInstance } from 'element-plus';
import _ from 'lodash';

defineOptions({
  name: 'UploadInsurePersonDialog',
});

type Props = {
  modelValue: boolean;
  form?: {
    serialNum: string;
    url: UploadUserFile[];
    productIdNumber: string;
  };
};

const props = withDefaults(defineProps<Props>(), {
  modelValue: false,
});

const emit = defineEmits<{
  (e: 'update:modelValue', value: boolean): void;
  (e: 'update:form', value: Props['form']): void;
  (e: 'onConfirm'): void;
  (e: 'onCancel'): void;
}>();

const { allUserInsureProductSettingList } = useUserInsureProductSetting();

const innerVisible = computed({
  get() {
    return props.modelValue;
  },
  set(val) {
    emit('update:modelValue', val);
  },
});

const innerForm = computed({
  get() {
    return props.form;
  },
  set(val) {
    emit('update:form', val);
  },
});

const dialogForm = ref<FormInstance>();

function onDialogClose() {
  if (!dialogForm.value) return;
  dialogForm.value.resetFields();
}

function handleConfirm() {
  if (!dialogForm.value) return;
  dialogForm.value.validate((valid) => {
    if (valid) {
      emit('onConfirm');
    } else {
      return;
    }
  });
}
</script>
